@@ -1,4 +1,5 @@
 import os
+import logging
 import requests
 
 url = os.getenv('PRINT_URL')
@@ -21,4 +22,9 @@ def print(*args, **kwargs):
 			'metadata': kwargs,
 			'token': token
 		}
-		return requests.post(url, json=json, timeout=1)
+
+		try:
+			return requests.post(url, json=json, timeout=1)
+
+		except Exception as e:
+			logging.error(e)
